import * as cloudfront from "aws-cdk-lib/aws-cloudfront";
import * as route53 from "aws-cdk-lib/aws-route53";
import { Construct } from "constructs";
export interface ICloudfrontAliasAssociatorProps {
    /**
     * @alias AKA "customDomain" or "the DNS record we want to affect".
     *
     * This is the domain name you want to move from one Cloudfront Distribution to another.
     * Will also work if it is NOT moving (on the first run).
     * */
    readonly alias: string;
    /**
     * The Route53 hosted zone that houses the customDomain.
     */
    readonly hostedZone: route53.IHostedZone;
    /**
     * The Cloudfront Distribution we want to move the alias to.
     */
    readonly targetDistribution: cloudfront.IDistribution;
}
/**
 * A simple construct to handle automated Cloudfront DNS alias migration with zero downtime.
 *
 * This creates:
 * - A TXT record with the name `_${alias}` that points to the targetDistributionDomainName.
 * - A Cloudfront custom resource "Custom::CloudfrontAssociateAlias" that associates the alias with the targetDistributionId.
 *   - Because we use the SDK here, this construct can be used as part of a versioned deployment, and can be used for both standard and rollback scenarios.
 * - A Route53 A and AAAA record that alias to the targetDistribution.
 */
export declare class CloudfrontAliasAssociator extends Construct {
    private readonly id;
    private readonly props;
    private readonly aliasTxtRecord;
    private readonly associatedAlias;
    constructor(scope: Construct, id: string, props: ICloudfrontAliasAssociatorProps);
    private createAliasTxtRecord;
    private associateAlias;
    private createAliasRecords;
}
